@@ -253,7 +253,7 @@ as.ab <- function(x, ...) {
         next
       }
     }
-    
+
     if (!isFALSE(list(...)$initial_search)) {
       # transform back from other languages and try again
       x_translated <- paste(lapply(strsplit(x[i], "[^a-zA-Z0-9 ]"),
@@ -294,6 +294,15 @@ as.ab <- function(x, ...) {
       }
     }
     
+    # try by removing all trailing capitals
+    if (x[i] %like_case% "[a-z]+[A-Z]+$") {
+      found <- suppressWarnings(as.ab(gsub("[A-Z]+$", "", x[i])))
+      if (length(found) > 0 & !is.na(found)) {
+        x_new[i] <- found[1L]
+        next
+      }
+    }
+    
     # not found
     x_unknown <- c(x_unknown, x_bak[x[i] == x_bak_clean][1])
   }
@@ -396,9 +405,15 @@ c.ab <- function(x, ...) {
   class_integrity_check(y, "antimicrobial code", antibiotics$ab)
 }
 
-#' @importFrom pillar type_sum
+#' @importFrom vctrs vec_ptype_abbr
 #' @export
-type_sum.ab <- function(x) {
+vec_ptype_abbr.ab <- function(x, ...) {
+  "ab"
+}
+
+#' @importFrom vctrs vec_ptype_full
+#' @export
+vec_ptype_full.ab <- function(x, ...) {
   "ab"
 }
 
