@@ -24,6 +24,7 @@ globalVariables(c(".",
                   "ab",
                   "ab_txt",
                   "abbreviations",
+                  "angle",
                   "antibiotic",
                   "antibiotics",
                   "CNS_CPS",
@@ -40,6 +41,7 @@ globalVariables(c(".",
                   "genus",
                   "gramstain",
                   "group",
+                  "hjust",
                   "index",
                   "input",
                   "interpretation",
@@ -100,7 +102,10 @@ globalVariables(c(".",
                   "txt",
                   "uncertainty_level",
                   "value",
+                  "varname",
                   "x",
                   "xdr",
+                  "xvar",
                   "y",
-                  "year"))
+                  "year",
+                  "yvar"))
