@@ -6,16 +6,16 @@
 # https://gitlab.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
-# (c) 2019 Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)  #
+# (c) 2018-2020 Berends MS, Luz CF et al.                              #
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
 # GNU General Public License version 2.0 (GNU GPL-2), as published by  #
 # the Free Software Foundation.                                        #
 #                                                                      #
-# This R package was created for academic research and was publicly    #
-# released in the hope that it will be useful, but it comes WITHOUT    #
-# ANY WARRANTY OR LIABILITY.                                           #
+# We created this package for both routine data analysis and academic  #
+# research and it was publicly released in the hope that it will be    #
+# useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 # Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
@@ -23,19 +23,14 @@
 .onLoad <- function(libname, pkgname) {
   # get new functions not available in older versions of R
   backports::import(pkgname)
-
+  
   # register data
-  microorganisms.oldDT <- as.data.table(AMR::microorganisms.old)
-  # for fullname_lower: keep only dots, letters, numbers, slashes, spaces and dashes
-  microorganisms.oldDT$fullname_lower <- gsub("[^.a-z0-9/ \\-]+", "", tolower(microorganisms.oldDT$fullname))
-  setkey(microorganisms.oldDT, prevalence, fullname)
-
   assign(x = "microorganismsDT",
          value = make_DT(),
          envir = asNamespace("AMR"))
 
   assign(x = "microorganisms.oldDT",
-         value = microorganisms.oldDT,
+         value = make_oldDT(),
          envir = asNamespace("AMR"))
 
   assign(x = "mo_codes_v0.5.0",
@@ -62,7 +57,9 @@ make_DT <- function() {
                                  # work with Viridans Group Streptococci, etc.
                                  tolower(trimws(ifelse(genus == "",
                                                        fullname,
-                                                       paste(genus, species, subspecies)))))) %>% 
+                                                       paste(genus, species, subspecies))))),
+           # add a column with only "e coli" like combinations
+           g_species = gsub("^([a-z])[a-z]+ ([a-z]+) ?.*", "\\1 \\2", fullname_lower)) %>% 
     as.data.table()
   
   # so arrange data on prevalence first, then kingdom, then full name
@@ -73,6 +70,25 @@ make_DT <- function() {
   microorganismsDT
 }
 
+#' @importFrom data.table as.data.table setkey
+#' @importFrom dplyr %>% mutate
+make_oldDT <- function() {
+  microorganisms.oldDT <- AMR::microorganisms.old %>% 
+    mutate(
+      # for fullname_lower: keep only dots, letters,
+      # numbers, slashes, spaces and dashes
+      fullname_lower = gsub("[^.a-z0-9/ \\-]+", "", tolower(fullname)),
+      # add a column with only "e coli" like combinations
+      g_species = gsub("^([a-z])[a-z]+ ([a-z]+) ?.*", "\\1 \\2", fullname_lower)) %>% 
+    as.data.table()
+  
+  # so arrange data on prevalence first, then full name
+  setkey(microorganisms.oldDT,
+         prevalence,
+         fullname)
+  microorganisms.oldDT
+}
+
 make_trans_tbl <- function() {
   # conversion of old MO codes from v0.5.0 (ITIS) to later versions (Catalogue of Life)
   c(B_ACHRMB = "B_ACHRM", B_ANNMA = "B_ACTNS", B_ACLLS = "B_ALCYC",
